<div>
    <div class="script_placeholder" data-src="{{ setup_script }}" />
    <input type="hidden"
           class="schematic"
           height="{{ height }}"
           width="{{ width }}"
           parts="{{ parts }}"
           analyses="{{ analyses }}"
           name="input_{{ id }}"
           id="input_{{ id }}"
           aria-label="{{ response_data.label|striptags }}"
           aria-describedby="answer_{{ id }}"
           value="{{ value }}"
           initial_value="{{ initial_value }}"
           submit_analyses="{{ submit_analyses }}" />
    <span id="answer_{{ id }}"></span>
    <div class="indicator-container">{% include "status_span.html" with status=status status_id=id %}</div>
</div>
