<section id="filesubmission_{{ id }}" class="filesubmission">
    <div class="grader-status file">
        <span class="{{ status.classname }}" id="status_{{ id }}">{{ status.display_name }}</span>
        {% if status == 'queued' %}<span style="display:none;" class="xqueue" id="{{ id }}">{{ queue_len }}</span>{% endif %}
        <p class="debug">{{ status }}</p>
        <input type="file"
               name="input_{{ id }}"
               id="input_{{ id }}"
               value="{{ value }}"
               multiple="multiple"
               data-required_files="{{ required_files }}"
               data-allowed_files="{{ allowed_files }}"
               aria-label="{{ response_data.label }}" />
    </div>
    <div class="message" tabindex="-1">{{ msg|safe }}</div>
</section>
