{% load static %}
<section id="designprotein2dinput_{{ id }}" class="designprotein2dinput">
    <div class="script_placeholder"
         data-src="{% static 'js/capa/protex/protex.nocache.js' %}" />
    <div class="script_placeholder" data-src="{{ applet_loader }}" />
    {% if status == 'unsubmitted' or status == 'correct' or status == 'incorrect' or status == 'partially-correct' or status == 'incomplete' %}
        <div class="{{ status.classname }}" id="status_{{ id }}">
        {% endif %}
        <div id="protex_container"></div>
        <input type="hidden"
               name="target_shape"
               id="target_shape"
               value="{{ target_shape }}">
    </input>
    <input type="hidden"
           name="input_{{ id }}"
           id="input_{{ id }}"
           aria-describedby="answer_{{ id }}"
           value="{{ value }}" />
    {% include "status_span.html" with status=status status_id=id %}
    <p id="answer_{{ id }}" class="answer"></p>
    {% if status == 'unsubmitted' or status == 'correct' or status == 'incorrect' or status == 'partially-correct' or status == 'incomplete' %}
    </div>
{% endif %}
</section>
