/* CSS for VideoBlock */

@import url("https://fonts.googleapis.com/css?family=Open+Sans:300,400,400i,600,700");

.xblock {
    margin-bottom: calc((var(--baseline, 20px) * 1.5));
}

.is-hidden,
.video.closed .subtitles {
    display: none;
}

.video {
    background: whitesmoke;
    display: block;
    margin: 0 -12px;
    padding: 12px;
    border-radius: 5px;
    outline: none;
}

.video:after {
    content: "";
    display: table;
    clear: both;
}

.video:focus,
.video:active,
.video:hover {
    border: 0;
}

.video.is-initialized .video-wrapper .spinner {
    display: none;
}

.video.is-pre-roll .slider {
    visibility: hidden;
}

.video.is-pre-roll .video-player {
    position: relative;
}

.video.is-pre-roll .video-player::before {
    display: block;
    content: "";
    width: 100%;
    padding-top: 55%;
}

.video .tc-wrapper {
    position: relative;
}

.video .tc-wrapper:after {
    content: "";
    display: table;
    clear: both;
}

.video .focus_grabber {
    position: relative;
    display: inline;
    width: 0;
    height: 0;
}

.video .downloads-heading {
    margin: 1em 0 0;
}

.video .wrapper-video-bottom-section {
    display: flex;
    justify-content: space-between;
}

.video .wrapper-video-bottom-section .wrapper-download-video,
.video .wrapper-video-bottom-section .wrapper-download-transcripts,
.video .wrapper-video-bottom-section .wrapper-handouts,
.video .wrapper-video-bottom-section ,
.video .wrapper-video-bottom-section .wrapper-transcript-feedback {
    margin-top: var(--baseline, 20px);
    padding-right: var(--baseline, 20px);
    vertical-align: top;
}

@media (min-width: 768px) {
    .video .wrapper-downloads {
        display: flex;
    }
}

.video .wrapper-downloads .hd {
    margin: 0;
}

.video .wrapper-downloads .wrapper-download-video .video-sources {
    /* Match it with Transcipts */
    font-size: 16px !important;
    font-weight: unset;
    margin: 0;
}

.video .wrapper-downloads .wrapper-download-transcripts .list-download-transcripts {
    margin: 0;
    padding: 0;
    list-style: none;
}

.video .wrapper-downloads .wrapper-download-transcripts .list-download-transcripts .transcript-option {
    display: flex;
    align-items: center;
    margin: 0;
}

.video .wrapper-downloads .wrapper-download-transcripts .list-download-transcripts .transcript-option a.btn,
.video .wrapper-downloads .wrapper-download-transcripts .list-download-transcripts .transcript-option a.btn-link {
    font-size: 16px !important;
    font-weight: unset;
    padding-left: 4px;
}

.video .wrapper-downloads {
    padding-right: 0;
}

.video .wrapper-downloads .host-tag {
    position: absolute;
    left: -9999em;
    display: inline-block;
    vertical-align: middle;
    color: var(--body-color, #313131);
}

.video .wrapper-downloads .brand-logo {
    display: inline-block;
    max-width: 100%;
    max-height: calc((var(--baseline, 20px) * 2));
    padding: calc((var(--baseline, 20px) / 4)) 0;
    vertical-align: middle;
}

.video .wrapper-transcript-feedback {
    display: none;
}

.video .wrapper-transcript-feedback .transcript-feedback-buttons {
    display: flex;
}

.video .wrapper-transcript-feedback .transcript-feedback-btn-wrapper {
    margin-right: 10px;
}

.video .wrapper-transcript-feedback .thumbs-up-btn,
.video .wrapper-transcript-feedback .thumbs-down-btn {
    border: none;
    box-shadow: none;
    background: transparent;
}

.video .google-disclaimer {
    display: none;
    margin-top: var(--baseline, 20px);
    padding-right: var(--baseline, 20px);
    vertical-align: top;
}

.video .video-wrapper {
    float: left;
    margin-right: 2.27273%;
    width: 65.90909%;
    background-color: black;
    position: relative;
}

.video .video-wrapper:hover .btn-play {
    color: #0075b4;
}

.video .video-wrapper:hover .btn-play::after {
    background: #fff;
}

.video .video-wrapper .video-player-pre,
.video .video-wrapper .video-player-post {
    height: 50px;
    background-color: #111010;
}

.video .video-wrapper .spinner {
    transform: translate(-50%, -50%);
    position: absolute;
    z-index: 1;
    background: rgba(0, 0, 0, 0.7);
    top: 50%;
    left: 50%;
    padding: 30px;
    border-radius: 25%;
}

.video .video-wrapper .spinner::after {
    animation: rotateCW 3s infinite linear;
    content: '';
    display: block;
    width: 30px;
    height: 30px;
    border: 7px solid white;
    border-top-color: transparent;
    border-radius: 100%;
    position: relative;
}

.video .video-wrapper .btn-play {
    transform: translate(-50%, -50%);
    position: absolute;
    z-index: 1;
    top: 46%;
    left: 50%;
    font-size: 4em;
    cursor: pointer;
    opacity: 0.1;
}

.video .video-wrapper .btn-play::after {
    background: var(--white, #fff);
    position: absolute;
    width: 50%;
    height: 50%;
    content: '';
    left: 0;
    top: 0;
    bottom: 0;
    right: 0;
    margin: auto;
    z-index: -1;
}

.video .video-wrapper .closed-captions {
    left: 5%;
    position: absolute;
    width: 90%;
    box-sizing: border-box;
    top: 70%;
    text-align: center;
}

.video .video-wrapper .closed-captions.is-visible {
    max-height: calc((var(--baseline, 20px) * 3));
    border-radius: calc((var(--baseline, 20px) / 5));
    padding: 8px calc((var(--baseline, 20px) / 2)) 8px calc((var(--baseline, 20px) * 1.5));
    background: rgba(0, 0, 0, 0.75);
    color: var(--yellow, #e2c01f);
}

.video .video-wrapper .closed-captions.is-visible::before {
    position: absolute;
    display: inline-block;
    top: 50%;
    left: var(--baseline, 20px);
    margin-top: -0.6em;
    font-family: 'FontAwesome';
    content: "\f142";
    color: var(--white, #fff);
    opacity: 0.5;
}

.video .video-wrapper .closed-captions.is-visible:hover,
.video .video-wrapper .closed-captions.is-visible.is-dragging {
    background: black;
    cursor: move;
}

.video .video-wrapper .closed-captions.is-visible:hover::before,
.video .video-wrapper .closed-captions.is-visible.is-dragging::before {
    opacity: 1;
}

.video .video-wrapper .video-player {
    overflow: hidden;
    min-height: 158px;
}

.video .video-wrapper .video-player>div {
    height: 100%;
}

.video .video-wrapper .video-player>div.hidden {
    display: none;
}

.video .video-wrapper .video-player .video-error,
.video .video-wrapper .video-player .video-hls-error {
    padding: calc((var(--baseline, 20px) / 5));
    background: black;
    color: white !important;
}

.video .video-wrapper .video-player object,
.video .video-wrapper .video-player iframe,
.video .video-wrapper .video-player video {
    left: 0;
    display: block;
    border: none;
    width: 100%;
}

.video .video-wrapper .video-player h4 {
    text-align: center;
    color: white;
}

.video .video-wrapper .video-player h4.hidden {
    display: none;
}

.video .video-wrapper .video-controls {
    position: relative;
    border: 0;
    background: #282c2e;
    color: #f0f3f5;
}

.video .video-wrapper .video-controls:after {
    content: "";
    display: table;
    clear: both;
}

.video .video-wrapper .video-controls:hover ul,
.video .video-wrapper .video-controls:hover div,
.video .video-wrapper .video-controls:focus ul,
.video .video-wrapper .video-controls:focus div {
    opacity: 1;
}

.video .video-wrapper .video-controls .control {
    display: inline-block;
    vertical-align: middle;
    margin: 0;
    border: 0;
    border-radius: 0;
    padding: calc((var(--baseline, 20px) / 2)) calc((var(--baseline, 20px) / 1.5));
    background: #282c2e;
    box-shadow: none;
    text-shadow: none;
    color: #cfd8dc;
}

.video .video-wrapper .video-controls .control:hover,
.video .video-wrapper .video-controls .control:focus {
    background: #171a1b;
}

.video .video-wrapper .video-controls .control:active,
.video .video-wrapper .video-controls .is-active.control,
.video .video-wrapper .video-controls .active.control {
    color: #0ea6ec;
}

.video .video-wrapper .video-controls .control .icon {
    width: 1em;
}

.video .video-wrapper .video-controls .control .icon.icon-hd {
    width: auto;
}

.video .video-wrapper .video-controls .slider {
    transform-origin: bottom left;
    transition: height 0.7s ease-in-out 0s;
    box-sizing: border-box;
    position: absolute;
    bottom: 100%;
    left: 0;
    right: 0;
    z-index: 1;
    height: calc((var(--baseline, 20px) / 4));
    margin-left: 0;
    border: 1px solid #4f595d;
    border-radius: 0;
    background: #4f595d;
}

.video .video-wrapper .video-controls .slider:after {
    content: "";
    display: table;
    clear: both;
}

.video .video-wrapper .video-controls .slider .ui-widget-header {
    background: #8e3e63;
    border: 1px solid #8e3e63;
    box-shadow: none;
    top: -1px;
    left: -1px;
}

.video .video-wrapper .video-controls .slider .ui-corner-all.slider-range {
    opacity: 0.3;
    background-color: #1e91d3;
}

.video .video-wrapper .video-controls .slider .ui-slider-handle {
    transform-origin: bottom left;
    transition: all 0.7s ease-in-out 0s;
    box-sizing: border-box;
    top: -1px;
    height: calc((var(--baseline, 20px) / 4));
    width: calc((var(--baseline, 20px) / 4));
    margin-left: calc(-1 * (var(--baseline, 20px) / 8));
    border: 1px solid #cb598d;
    border-radius: calc((var(--baseline, 20px) / 5));
    padding: 0;
    background: #cb598d;
    box-shadow: none;
}

.video .video-wrapper .video-controls .slider .ui-slider-handle:focus,
.video .video-wrapper .video-controls .slider .ui-slider-handle:hover {
    background-color: #db8baf;
    border-color: #db8baf;
}

.video .video-wrapper .video-controls .vcr {
    float: left;
    list-style: none;
    border-right: 1px solid #282c2e;
    padding: 0;
}

@media (max-width: 1120px) {
    .video .video-wrapper .video-controls .vcr {
        margin-right: lh(0.5);
        font-size: 0.875em;
    }
}

.video .video-wrapper .video-controls .vcr .video_control:focus {
    position: relative;
}

.video .video-wrapper .video-controls .vcr .video_control.skip {
    white-space: nowrap;
}

.video .video-wrapper .video-controls .vcr .vidtime {
    padding-left: lh(0.75);
    display: inline-block;
    color: #cfd8dc;
    -webkit-font-smoothing: antialiased;
}

@media (max-width: 1120px) {
    .video .video-wrapper .video-controls .vcr .vidtime {
        padding-left: lh(0.5);
    }
}

.video .video-wrapper .video-controls .secondary-controls {
    float: right;
    border-left: 1px dotted #4f595d;
}

.video .video-wrapper .video-controls .secondary-controls .volume,
.video .video-wrapper .video-controls .secondary-controls .add-fullscreen,
.video .video-wrapper .video-controls .secondary-controls .grouped-controls,
.video .video-wrapper .video-controls .secondary-controls .auto-advance,
.video .video-wrapper .video-controls .secondary-controls .quality-control {
    border-left: 1px dotted #4f595d;
}

.video .video-wrapper .video-controls .secondary-controls .speed-button:focus,
.video .video-wrapper .video-controls .secondary-controls .volume>.control:focus,
.video .video-wrapper .video-controls .secondary-controls .add-fullscreen:focus,
.video .video-wrapper .video-controls .secondary-controls .auto-advance:focus,
.video .video-wrapper .video-controls .secondary-controls .quality-control:focus,
.video .video-wrapper .video-controls .secondary-controls .toggle-transcript:focus {
    position: relative;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container {
    position: relative;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container .menu {
    transition: none;
    position: absolute;
    display: none;
    bottom: 100%;
    right: 0;
    width: 120px;
    margin: 0;
    border: none;
    padding: 0;
    box-shadow: none;
    background-color: #282c2e;
    list-style: none;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li {
    color: #e7ecee;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li .speed-option,
.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li .control-lang {
    text-align: left;
    display: block;
    width: 100%;
    border: 0;
    border-radius: 0;
    padding: lh(0.5);
    background: #282c2e;
    box-shadow: none;
    color: #e7ecee;
    overflow: hidden;
    text-shadow: none;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li .speed-option:hover,
.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li .speed-option:focus,
.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li .control-lang:hover,
.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li .control-lang:focus {
    background-color: #4f595d;
    color: #fcfcfc;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li.is-active .speed-option,
.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li.is-active .control-lang {
    border-left: calc(var(--baseline, 20px) / 10) solid #90d7f9;
    font-weight: var(--font-bold, 700);
    color: #90d7f9;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container.is-opened .menu {
    display: block;
}

.video .video-wrapper .video-controls .secondary-controls .speeds,
.video .video-wrapper .video-controls .secondary-controls .lang,
.video .video-wrapper .video-controls .secondary-controls .grouped-controls {
    display: inline-block;
}

.video .video-wrapper .video-controls .secondary-controls .speeds.is-opened .control .icon {
    transform: rotate(-90deg);
}

.video .video-wrapper .video-controls .secondary-controls .speeds .speed-button .label {
    padding: 0 calc((var(--baseline, 20px) / 3)) 0 0;
    font-family: var(--font-family-sans-serif);
    color: #e7ecee;
}

@media (max-width: 1120px) {
    .video .video-wrapper .video-controls .secondary-controls .speeds .speed-button .label {
        position: absolute;
        clip: rect(1px, 1px, 1px, 1px);
    }
}

.video .video-wrapper .video-controls .secondary-controls .speeds .speed-button .value {
    padding: 0 lh(0.5) 0 0;
    color: #e7ecee;
    font-weight: bold;
}

@media (max-width: 1120px) {
    .video .video-wrapper .video-controls .secondary-controls .speeds .speed-button .value {
        padding: 0 lh(0.5);
    }
}

.video .video-wrapper .video-controls .secondary-controls .lang .language-menu {
    width: var(--baseline, 20px);
    padding: calc((var(--baseline, 20px) / 2)) 0;
}

.video .video-wrapper .video-controls .secondary-controls .lang.is-opened .control .icon {
    transform: rotate(90deg);
}

.video .video-wrapper .video-controls .secondary-controls .volume {
    display: inline-block;
    position: relative;
}

.video .video-wrapper .video-controls .secondary-controls .volume.is-opened .volume-slider-container {
    display: block;
    opacity: 1;
}

.video .video-wrapper .video-controls .secondary-controls .volume:not(:first-child)>a {
    border-left: none;
}

.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container {
    transition: none;
    display: none;
    position: absolute;
    bottom: 100%;
    right: 0;
    width: 41px;
    height: 120px;
    background-color: #282c2e;
}

.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container .volume-slider {
    height: 100px;
    width: calc((var(--baseline, 20px) / 4));
    margin: 14px auto;
    box-sizing: border-box;
    border: 1px solid #4f595d;
    background: #4f595d;
}

.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container .volume-slider .ui-slider-handle {
    transition: height var(--tmg-s2, 2s) ease-in-out 0s, width var(--tmg-s2, 2s) ease-in-out 0s;
    left: -5px;
    box-sizing: border-box;
    height: 13px;
    width: 13px;
    border: 1px solid #cb598d;
    border-radius: calc((var(--baseline, 20px) / 5));
    padding: 0;
    background: #cb598d;
    box-shadow: none;
}

.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container .volume-slider .ui-slider-handle:hover,
.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container .volume-slider .ui-slider-handle:focus {
    background: #db8baf;
    border-color: #db8baf;
}

.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container .volume-slider .ui-slider-range {
    background: #8e3e63;
    border: 1px solid #8e3e63;
    left: -1px;
    bottom: -1px;
}

.video .video-wrapper .video-controls .secondary-controls .quality-control {
    font-weight: 700;
    letter-spacing: -1px;
}

.video .video-wrapper .video-controls .secondary-controls .quality-control.active {
    color: #0ea6ec;
}

.video .video-wrapper .video-controls .secondary-controls .quality-control.is-hidden,
.video.closed .video-wrapper .video-controls .secondary-controls .quality-control.subtitles {
    display: none !important;
}

.video .video-wrapper .video-controls .secondary-controls .toggle-transcript.is-active {
    color: #0ea6ec;
}

.video .video-wrapper .video-controls .secondary-controls .lang>.hide-subtitles {
    transition: none;
}

.video .video-wrapper:hover .video-controls .slider {
    height: calc((var(--baseline, 20px) / 1.5));
}

.video .video-wrapper:hover .video-controls .slider .ui-slider-handle {
    height: calc((var(--baseline, 20px) / 1.5));
    width: calc((var(--baseline, 20px) / 1.5));
}

.video.video-fullscreen .closed-captions {
    width: 65%;
}

.video.video-fullscreen.closed .closed-captions {
    width: 90%;
}

.video .subtitles {
    float: left;
    overflow: auto;
    max-height: 460px;
    width: 31.81818%;
    padding: 0;
    font-size: 14px;
    visibility: visible;
}

.video .subtitles a {
    color: #0074b5;
}

.video .subtitles .subtitles-menu {
    height: 100%;
    margin: 0;
    padding: 0 3px;
    list-style: none;
}

.video .subtitles .subtitles-menu li {
    margin-bottom: 8px;
    border: 0;
    padding: 0;
    color: #0074b5;
    line-height: lh();
}

.video .subtitles .subtitles-menu li:has(> span:empty) {
  display: none;
}

.video .subtitles .subtitles-menu li span {
    display: block;
}

.video .subtitles .subtitles-menu li.current {
    color: #333;
    font-weight: 700;
}

.video .subtitles .subtitles-menu li.focused {
    outline: #000 dotted thin;
    outline-offset: -1px;
}

.video .subtitles .subtitles-menu li:hover,
.video .subtitles .subtitles-menu li:focus {
    text-decoration: underline;
}

.video .subtitles .subtitles-menu li:empty {
    margin-bottom: 0;
}

.video .subtitles .subtitles-menu li.spacing:last-of-type {
    position: relative;
}

.video .subtitles .subtitles-menu li.spacing:last-of-type .transcript-end {
    position: absolute;
    bottom: 0;
}

.video.closed .video-wrapper {
    width: 100%;
    background-color: inherit;
}

.video.closed .video-wrapper .video-controls.html5 {
    bottom: 0;
    left: 0;
    right: 0;
    position: absolute;
    z-index: 1;
}

.video.closed .video-wrapper .video-player-pre,
.video.closed .video-wrapper .video-player-post {
    height: 0;
}

.video.closed .video-wrapper .video-player h3 {
    color: black;
}

.video.closed .subtitles.html5 {
    background-color: rgba(243, 243, 243, 0.8);
    height: 100%;
    position: absolute;
    right: 0;
    bottom: 0;
    top: 0;
    width: 275px;
    padding: 0 var(--baseline, 20px);
    display: none;
}

.video.video-fullscreen {
    background: rgba(0, 0, 0, 0.95);
    border: 0;
    bottom: 0;
    height: 100%;
    left: 0;
    margin: 0;
    padding: 0;
    position: fixed;
    top: 0;
    width: 100%;
    vertical-align: middle;
    border-radius: 0;
}

.video.video-fullscreen.closed .tc-wrapper .video-wrapper {
    width: 100%;
}

.video.video-fullscreen .video-wrapper .video-player-pre,
.video.video-fullscreen .video-wrapper .video-player-post {
    height: 0;
}

.video.video-fullscreen .video-wrapper {
    position: static;
}

.video.video-fullscreen .video-wrapper .video-player h3 {
    color: white;
}

.video.video-fullscreen .tc-wrapper {
    width: 100%;
    height: 100%;
    position: static;
}

.video.video-fullscreen .tc-wrapper:after {
    content: "";
    display: table;
    clear: both;
}

.video.video-fullscreen .tc-wrapper .video-wrapper {
    height: 100%;
    width: 75%;
    margin-right: 0;
    vertical-align: middle;
}

.video.video-fullscreen .tc-wrapper .video-wrapper object,
.video.video-fullscreen .tc-wrapper .video-wrapper iframe,
.video.video-fullscreen .tc-wrapper .video-wrapper video {
    position: absolute;
    width: auto;
    height: auto;
}

.video.video-fullscreen .tc-wrapper .video-controls {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
}

.video.video-fullscreen .subtitles {
    height: 100%;
    width: 25%;
    padding: lh();
    box-sizing: border-box;
    transition: none;
    background: var(--black, #000);
    visibility: visible;
}

.video.video-fullscreen .subtitles li {
    color: #aaa;
}

.video.video-fullscreen .subtitles li.current {
    color: var(--white, #fff);
}

.video.is-touch .tc-wrapper .video-wrapper object,
.video.is-touch .tc-wrapper .video-wrapper iframe,
.video.is-touch .tc-wrapper .video-wrapper video {
    width: 100%;
    height: 100%;
}

.video .video-pre-roll {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-position: 50% 50%;
    background-repeat: no-repeat;
    background-size: 100%;
    background-color: var(--black, #000);
}

.video .video-pre-roll.is-html5 {
    background-size: 15%;
}

.video .video-pre-roll .btn-play.btn-pre-roll {
    padding: var(--baseline, 20px);
    border: none;
    border-radius: var(--baseline, 20px);
    background: var(--black-t2, rgba(0, 0, 0, 0.5));
    box-shadow: none;
}

.video .video-pre-roll .btn-play.btn-pre-roll::after {
    display: none;
}

.video .video-pre-roll .btn-play.btn-pre-roll img {
    height: calc((var(--baseline, 20px) * 4));
    width: calc((var(--baseline, 20px) * 4));
}

.video .video-pre-roll .btn-play.btn-pre-roll:hover,
.video .video-pre-roll .btn-play.btn-pre-roll:focus {
    background: var(--blue, #0075b4);
}

.video .video-wrapper .video-controls .slider .ui-slider-handle,
.video .video-wrapper .video-controls .secondary-controls .menu-container .menu li,
.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container .volume-slider .ui-slider-handle,
.video .subtitles .subtitles-menu li,
.a11y-menu-container .a11y-menu-list li {
    cursor: pointer;
}

.video.closed .subtitles.html5 {
    z-index: 0;
}

.video .video-wrapper .video-controls .secondary-controls .menu-container .menu,
.video .video-wrapper .video-controls .secondary-controls .volume .volume-slider-container {
    z-index: 10;
}

.video .video-pre-roll,
.a11y-menu-container .a11y-menu-list {
    z-index: 1000;
}

.video.video-fullscreen,
.video.video-fullscreen .tc-wrapper .video-controls,
.overlay {
    z-index: 10000;
}

.contextmenu,
.submenu {
    z-index: 100000;
}

.video-tracks .a11y-menu-container>a::after {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    display: inline-block;
    speak: none;
}

.a11y-menu-container {
    position: relative;
}

.a11y-menu-container.open .a11y-menu-list {
    display: block;
}

.a11y-menu-container .a11y-menu-list {
    top: 100%;
    margin: 0;
    padding: 0;
    display: none;
    position: absolute;
    list-style: none;
    background-color: var(--white, #fff);
    border: 1px solid #eee;
}

.a11y-menu-container .a11y-menu-list li {
    margin: 0;
    padding: 0;
    border-bottom: 1px solid #eee;
    color: var(--white, #fff);
}

.a11y-menu-container .a11y-menu-list li a {
    display: block;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: var(--gray-l2, #adadad);
    font-size: 14px;
    line-height: 23px;
}

.a11y-menu-container .a11y-menu-list li a:hover,
.a11y-menu-container .a11y-menu-list li a:focus {
    color: var(--gray-d1, #5e5e5e);
}

.a11y-menu-container .a11y-menu-list li.active a {
    color: #009fe6;
}

.a11y-menu-container .a11y-menu-list li:last-child {
    box-shadow: none;
    border-bottom: 0;
    margin-top: 0;
}

.video-tracks .a11y-menu-container {
    display: inline-block;
    vertical-align: top;
    border-left: 1px solid #eee;
}

.video-tracks .a11y-menu-container.open>a {
    background-color: var(--action-primary-active-bg, #0075b4);
    color: var(--very-light-text, white);
}

.video-tracks .a11y-menu-container.open>a::after {
    color: var(--very-light-text, white);
}

.video-tracks .a11y-menu-container>a {
    transition: all var(--tmg-f2, 0.25s) ease-in-out 0s;
    font-size: 12px;
    display: block;
    border-radius: 0 3px 3px 0;
    background-color: var(--very-light-text, white);
    padding: calc((var(--baseline, 20px) * 0.75)) calc((var(--baseline, 20px) * 1.25)) calc((var(--baseline, 20px) * 0.75)) calc((var(--baseline, 20px) * 0.75));
    color: var(--gray-l2, #adadad);
    min-width: 1.5em;
    line-height: 14px;
    text-align: center;
    overflow: hidden;
    text-overflow: ellipsis;
}

.video-tracks .a11y-menu-container>a::after {
    content: "\f0d7";
    position: absolute;
    right: calc((var(--baseline, 20px) * 0.5));
    top: 33%;
    color: var(--lighter-base-font-color, #646464);
}

.video-tracks .a11y-menu-container .a11y-menu-list {
    right: 0;
}

.video-tracks .a11y-menu-container .a11y-menu-list li {
    font-size: 0.875em;
}

.video-tracks .a11y-menu-container .a11y-menu-list li a {
    border: 0;
    display: block;
    padding: 0.70788em;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.contextmenu,
.submenu {
    border: 1px solid #333;
    background: var(--white, #fff);
    color: #333;
    padding: 0;
    margin: 0;
    list-style: none;
    position: absolute;
    top: 0;
    display: none;
    outline: none;
    cursor: default;
    white-space: nowrap;
}

.contextmenu.is-opened,
.submenu.is-opened {
    display: block;
}

.contextmenu .menu-item,
.contextmenu .submenu-item,
.submenu .menu-item,
.submenu .submenu-item {
    border-top: 1px solid var(--gray-l3, #c8c8c8);
    padding: calc((var(--baseline, 20px) / 4)) calc((var(--baseline, 20px) / 2));
    outline: none;
}

.contextmenu .menu-item>span,
.contextmenu .submenu-item>span,
.submenu .menu-item>span,
.submenu .submenu-item>span {
    color: #333;
}

.contextmenu .menu-item:first-child,
.contextmenu .submenu-item:first-child,
.submenu .menu-item:first-child,
.submenu .submenu-item:first-child {
    border-top: none;
}

.contextmenu .menu-item:focus,
.contextmenu .submenu-item:focus,
.submenu .menu-item:focus,
.submenu .submenu-item:focus {
    background: #333;
    color: var(--white, #fff);
}

.contextmenu .menu-item:focus>span,
.contextmenu .submenu-item:focus>span,
.submenu .menu-item:focus>span,
.submenu .submenu-item:focus>span {
    color: var(--white, #fff);
}

.contextmenu .submenu-item,
.submenu .submenu-item {
    position: relative;
    padding: calc((var(--baseline, 20px) / 4)) var(--baseline, 20px) calc((var(--baseline, 20px) / 4)) calc((var(--baseline, 20px) / 2));
}

.contextmenu .submenu-item::after,
.submenu .submenu-item::after {
    content: '\25B6';
    position: absolute;
    right: 5px;
    line-height: 25px;
    font-size: 10px;
}

.contextmenu .submenu-item .submenu,
.submenu .submenu-item .submenu {
    display: none;
}

.contextmenu .submenu-item.is-opened,
.submenu .submenu-item.is-opened {
    background: #333;
    color: var(--white, #fff);
}

.contextmenu .submenu-item.is-opened>span,
.submenu .submenu-item.is-opened>span {
    color: var(--white, #fff);
}

.contextmenu .submenu-item.is-opened>.submenu,
.submenu .submenu-item.is-opened>.submenu {
    display: block;
}

.contextmenu .submenu-item .is-selected,
.submenu .submenu-item .is-selected {
    font-weight: bold;
}

.contextmenu .is-disabled,
.submenu .is-disabled {
    pointer-events: none;
    color: var(--gray-l3, #c8c8c8);
}

.overlay {
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-color: transparent;
}

.wrapper-social-share .social-toggle-btn {
    background: var(--primary);
    font-size: 13px;
    font-weight: 700;
    padding: calc(var(--baseline) * 0.35) calc(var(--baseline) * 0.9);
    color: var(--white);
    box-shadow: none;
    text-shadow: none;
    border-radius: 3px;
    border: none;
}

.wrapper-social-share .social-toggle-btn:hover,
.wrapper-social-share .social-toggle-btn:focus {
    background: var(--btn-brand-focus-background);
}

.wrapper-social-share .social-toggle-btn .fa {
    margin-right: calc(var(--baseline) * 0.4);
}

.wrapper-social-share .container-social-share {
    padding: calc(var(--baseline) * 0.4);
    width: 300px;
    border-radius: 6px;
    background-color: var(--white);
    box-shadow: rgba(0, 0, 0, 0.15) 0 0.5rem 1rem, rgba(0, 0, 0, 0.15) 0 0.25rem 0.625rem;
}

.wrapper-social-share .container-social-share .close-btn {
    float: right;
    cursor: pointer;
    vertical-align: top;
    display: inline-flex;
    color: var(--black);
    text-decoration: none !important;
}

.wrapper-social-share .container-social-share .social-share-link {
    margin-right: calc(var(--baseline) * 0.2);
    font-size: 24px;
    height: 24px;
    vertical-align: middle;
    text-decoration: none;
    display: inline-flex;
}

.wrapper-social-share .container-social-share .social-share-link > span > svg {
    width: auto;
    height: 24px;
    vertical-align: top;
    display: inline-flex;
}

.wrapper-social-share .container-social-share .public-video-url-container {
    padding: calc(var(--baseline) * 0.4);
    display: flex;
    align-items: center;
    justify-content: space-between;
    background-color: #f2f0ef;
}

.wrapper-social-share .container-social-share .public-video-url-link {
    color: var(--black);
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: middle;
    white-space: nowrap;
}

.wrapper-social-share .container-social-share .public-video-url-link:hover {
    text-decoration: underline;
}

.wrapper-social-share .container-social-share .public-video-copy-btn {
    margin-left: calc(var(--baseline) * 0.7);
    flex-shrink: 0;
    color: var(--primary);
    cursor: pointer;
}

.wrapper-social-share .container-social-share .public-video-copy-btn:hover {
    text-decoration: none;
    color: var(--link-hover-color);
}
