{% load i18n %}
<div class="pdf_block">
  <h2>{{ display_name }}</h2>
  <iframe src="{{ url }}" type="application/pdf" width="100%" height="600">

  </iframe>
  {% if not disable_all_download %}
  <ul>
    {% if allow_download %}
      <li class="pdf-download-button">
          <a href="{{ url }}" target="_blank" rel="noopener" download>{% trans "Download the PDF" %}</a>
          (Right click or long press on the download link and select the "Save as" option to download. Clicking on the link might open it in a tab.)
      </li>
    {% endif %}
    {% if source_url != "" %}
    <li class="pdf-download-button">
      <a href="{{ source_url }}" download>{% if source_text == "" %}{% trans "Download the source document" %}{% else %}{{ source_text }}{% endif %}</a>
    </li>
    {% endif %}
  </ul>
  {% endif %}
</div>
